@@ -5,6 +5,7 @@ import subprocess
 import sys
 import tempfile
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Type, Union
+from packaging import version
 
 from dda_python_terraform.tfstate import Tfstate
 
@@ -52,7 +53,7 @@ class Terraform:
         var_file: Optional[str] = None,
         terraform_bin_path: Optional[str] = None,
         is_env_vars_included: bool = True,
-        terraform_version: Optional[float] = 0.13
+        terraform_semantic_version: Optional[str] = "0.13.0"
     ):
         """
         :param working_dir: the folder of the working folder, if not given,
@@ -69,6 +70,7 @@ class Terraform:
         :param terraform_bin_path: binary path of terraform
         :type is_env_vars_included: bool
         :param is_env_vars_included: included env variables when calling terraform cmd
+        :param terrform_semantic_version encodes major.minor.patch version of terraform. Defaults to 0.13.0
         """
         self.is_env_vars_included = is_env_vars_included
         self.working_dir = working_dir
@@ -79,7 +81,7 @@ class Terraform:
         self.terraform_bin_path = (
             terraform_bin_path if terraform_bin_path else "terraform"
         )
-        self.terraform_version = terraform_version
+        self.terraform_semantic_version = terraform_semantic_version
         self.var_file = var_file
         self.temp_var_files = VariableFiles()
 
@@ -156,7 +158,7 @@ class Terraform:
         global_opts = self._generate_default_general_options(dir_or_plan)
         default = kwargs.copy()
         # force is no longer a flag in version >= 1.0
-        if self.terraform_version < 1.0:
+        if version.parse(self.terraform_semantic_version) < version.parse("1.0.0"):
             default["force"] = force
         default["auto-approve"] = True
         options = self._generate_default_options(default)
@@ -437,14 +439,34 @@ class Terraform:
         global_opts = self._generate_default_general_options(False)
         return self.cmd(global_opts, "workspace", "show", **kwargs)
 
+    def list_workspace(self) -> List[str]:
+        """List of workspaces
+
+        :return: workspaces
+        :example:
+            >>> tf = Terraform()
+            >>> tf.list_workspace()
+            ['default', 'test']
+        """
+        global_opts = self._generate_default_general_options(False)
+        return list(
+            filter(
+                lambda workspace: len(workspace) > 0,
+                map(
+                    lambda workspace: workspace.strip('*').strip(),                    
+                    (self.cmd(global_opts, "workspace", "list")[1] or '').split()
+                )
+            )
+        )
+
     def _generate_default_args(self, dir_or_plan: Optional[str]) -> Sequence[str]:
-        if (self.terraform_version < 1.0 and dir_or_plan):
+        if (version.parse(self.terraform_semantic_version) < version.parse("1.0.0") and dir_or_plan):
             return [dir_or_plan]
         else:
             return []
 
     def _generate_default_general_options(self, dir_or_plan: Optional[str]) -> Dict[str, Any]:
-        if (self.terraform_version >= 1.0 and dir_or_plan):
+        if (version.parse(self.terraform_semantic_version) >= version.parse("1.0.0") and dir_or_plan):
             return {"chdir": dir_or_plan}
         else:
             return {}
@@ -467,7 +489,7 @@ class Terraform:
         """
         """
         result = []
-        
+
         for option, value in kwargs.items():
             if "_" in option:
                 option = option.replace("_", "-")
@@ -507,10 +529,10 @@ class Terraform:
 
             result += [f"-{option}={value}"]
         return result
-    
+
     def __exit__(self, exc_type, exc_value, traceback) -> None:
         self.temp_var_files.clean_up()
-    
+
     def __getattr__(self, item: str) -> Callable:
         def wrapper(*args, **kwargs):
             cmd_name = str(item)
@@ -522,7 +544,6 @@ class Terraform:
 
         return wrapper
 
-    
 
 
 class VariableFiles:
